@@ -1,8 +1,34 @@
-package Querylet::Output::Text;
-use base qw(Querylet::Output);
-
-use warnings;
 use strict;
+use warnings;
+package Querylet::Output::Text;
+{
+  $Querylet::Output::Text::VERSION = '0.113';
+}
+use parent qw(Querylet::Output);
+# ABSTRACT: output querylet results to text tables
+
+use Text::Table;
+
+
+sub default_type { 'text' }
+
+
+sub handler      { \&_as_text_table }
+sub _as_text_table {
+	my ($query) = @_;
+	my $results = $query->results;
+	my $columns = $query->columns;
+
+	my $table = Text::Table->new(map { $query->header($_) } @$columns);
+	   $table->load(map { [ @$_{@$columns} ] }  @$results);
+	return "$table";
+}
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
@@ -10,15 +36,7 @@ Querylet::Output::Text - output querylet results to text tables
 
 =head1 VERSION
 
-version 0.112
-
- $Id: /my/cs/projects/q/text/trunk/lib/Querylet/Output/Text.pm 28174 2006-11-16T13:38:21.823039Z rjbs  $
-
-=cut
-
-our $VERSION = '0.112';
-
-use Text::Table;
+version 0.113
 
 =head1 SYNOPSIS
 
@@ -41,54 +59,26 @@ use Text::Table;
 This module registers an output handler to produce plaintext tables, using
 Text::Table.
 
-=over 4
+=head1 METHODS
 
-=item C<< default_type >>
+=head2 default_type
 
 The default type for Querylet::Output::Text is "text"
 
-=cut
-
-sub default_type { 'text' }
-
-=item C<< handler >>
+=head2 handler
 
 The output handler uses Text::Table to print a simple table, suitable for
 reading at the console.
 
-=cut
-
-sub handler      { \&_as_text_table }
-sub _as_text_table {
-	my ($query) = @_;
-	my $results = $query->results;
-	my $columns = $query->columns;
-
-	my $table = Text::Table->new(map { $query->header($_) } @$columns);
-	   $table->load(map { [ @$_{@$columns} ] }  @$results);
-	return "$table";
-}
-
-=back
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-querylet-output-text@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004 Ricardo SIGNES, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
